==> ismah-3.0.1%2B1.19.4%2Bfabric-sources.jar: com/github/razorplay01/ismah/client/api/ArmorRendererRegistry.java <==
package com.github.razorplay01.ismah.client.api;

import java.util.ArrayList;
import java.util.List;
import java.util.function.Function;
import net.minecraft.class_1657;
import net.minecraft.class_1799;

/**
 * Registry for custom armor renderers in first-person view.
 * This class allows mod developers to register their implementations of {@link CustomArmorRenderer}
 * to handle custom armor rendering on the player's arm in first-person perspective.
 */
public class ArmorRendererRegistry {
    private ArmorRendererRegistry() {
        // []
    }

    private static final List<CustomArmorRenderer> renderers = new ArrayList<>();
    private static final List<Function<class_1657, class_1799>> chestplateProviders = new ArrayList<>();

    /**
     * Registers a custom armor renderer.
     * Mods should call this method during initialization to add their renderer to the registry.
     * Renderers are checked in the order they are registered, and the first matching renderer
     * for an ItemStack will be used.
     *
     * @param renderer The custom armor renderer to register.
     */
    public static void register(CustomArmorRenderer renderer) {
        renderers.add(renderer);
    }

    /**
     * Retrieves the first registered renderer that can handle the given ItemStack.
     * This method is used internally by the ISMAH mod to determine which renderer to use.
     *
     * @param stack The ItemStack of the equipped armor.
     * @return The first {@link CustomArmorRenderer} that returns {@code true} for {@link CustomArmorRenderer#canRender},
     * or {@code null} if no renderer matches.
     */
    public static CustomArmorRenderer getRenderer(class_1799 stack) {
        for (CustomArmorRenderer renderer : renderers) {
            if (renderer.canRender(stack)) {
                return renderer;
            }
        }
        return null;
    }

    public static void registerChestplateProvider(Function<class_1657, class_1799> provider) {
        chestplateProviders.add(provider);
    }
    //? if >= 1.19 && <= 1.21.4 {
    public static class_1799 getChestplate(class_1657 player) {
        for (Function<class_1657, class_1799> provider : chestplateProviders) {
            class_1799 stack = provider.apply(player);
            if (stack != null && !stack.method_7960() && stack.method_7909() instanceof net.minecraft.class_1738) {
                return stack;
            }
        }
        return player.method_31548().method_7372(2);
    }
    //?}

    //? if >= 1.21.5 {
    /*public static ItemStack getChestplate(Player player) {
        for (Function<Player, ItemStack> provider : chestplateProviders) {
            ItemStack stack = provider.apply(player);
            if (stack != null && !stack.isEmpty()) {
                net.minecraft.world.item.equipment.Equippable equippable = stack.get(net.minecraft.core.component.DataComponents.EQUIPPABLE);
                if (equippable.slot() == net.minecraft.world.entity.EquipmentSlot.CHEST) {
                    return stack;
                }
            }
        }
        return ((com.github.razorplay01.ismah.common.mixin.InventoryAccessor) player.getInventory()).getEquipment().get(net.minecraft.world.entity.EquipmentSlot.CHEST);
    }
    *///?}
}

==> ismah-3.3.0%2B1.21.9%2Bfabric-sources.jar: com/github/razorplay01/ismah/client/api/ArmorRendererRegistry.java <==
package com.github.razorplay01.ismah.client.api;

import java.util.ArrayList;
import java.util.List;
import java.util.function.Function;
import net.minecraft.class_1657;
import net.minecraft.class_1799;

/**
 * Registry for custom armor renderers in first-person view.
 * This class allows mod developers to register their implementations of {@link CustomArmorRenderer}
 * to handle custom armor rendering on the player's arm in first-person perspective.
 */
public class ArmorRendererRegistry {
    private ArmorRendererRegistry() {
        // []
    }

    private static final List<CustomArmorRenderer> renderers = new ArrayList<>();
    private static final List<Function<class_1657, class_1799>> chestplateProviders = new ArrayList<>();

    /**
     * Registers a custom armor renderer.
     * Mods should call this method during initialization to add their renderer to the registry.
     * Renderers are checked in the order they are registered, and the first matching renderer
     * for an ItemStack will be used.
     *
     * @param renderer The custom armor renderer to register.
     */
    public static void register(CustomArmorRenderer renderer) {
        renderers.add(renderer);
    }

    /**
     * Retrieves the first registered renderer that can handle the given ItemStack.
     * This method is used internally by the ISMAH mod to determine which renderer to use.
     *
     * @param stack The ItemStack of the equipped armor.
     * @return The first {@link CustomArmorRenderer} that returns {@code true} for {@link CustomArmorRenderer#canRender},
     * or {@code null} if no renderer matches.
     */
    public static CustomArmorRenderer getRenderer(class_1799 stack) {
        for (CustomArmorRenderer renderer : renderers) {
            if (renderer.canRender(stack)) {
                return renderer;
            }
        }
        return null;
    }

    public static void registerChestplateProvider(Function<class_1657, class_1799> provider) {
        chestplateProviders.add(provider);
    }
    //? if >= 1.19 && <= 1.21.4 {
    /*public static ItemStack getChestplate(Player player) {
        for (Function<Player, ItemStack> provider : chestplateProviders) {
            ItemStack stack = provider.apply(player);
            if (stack != null && !stack.isEmpty() && stack.getItem() instanceof net.minecraft.world.item.ArmorItem) {
                return stack;
            }
        }
        return player.getInventory().getArmor(2);
    }
    *///?}

    //? if >= 1.21.5 {
    public static class_1799 getChestplate(class_1657 player) {
        for (Function<class_1657, class_1799> provider : chestplateProviders) {
            class_1799 stack = provider.apply(player);
            if (stack != null && !stack.method_7960()) {
                net.minecraft.class_10192 equippable = stack.method_58694(net.minecraft.class_9334.field_54196);
                if (equippable.comp_3174() == net.minecraft.class_1304.field_6174) {
                    return stack;
                }
            }
        }
        return ((com.github.razorplay01.ismah.common.mixin.InventoryAccessor) player.method_31548()).getEquipment().method_66659(net.minecraft.class_1304.field_6174);
    }
    //?}
}
